==> pcb-rnd_2.0.1.orig.tar.bz2: pcb-rnd-2.0.1/src_plugins/gpmi/pcb-gpmi/gpmi_plugin/gpmi_pkg/hid/hid_callbacks.h <==
pcb_hid_attribute_t *gpmi_hid_get_export_options(int *num);
pcb_hid_gc_t gpmi_hid_make_gc(void);
void gpmi_hid_destroy_gc(pcb_hid_gc_t gc);
void gpmi_hid_do_export(pcb_hid_attr_val_t * options);
int gpmi_hid_parse_arguments(int *pcbargc, char ***pcbargv);
void gpmi_hid_set_crosshair(pcb_coord_t x, pcb_coord_t y, int cursor_action);
int gpmi_hid_set_layer_group(pcb_layergrp_id_t group, pcb_layer_id_t layer, unsigned int flags, int is_empty);
void gpmi_hid_set_color(pcb_hid_gc_t gc, const char *name);
void gpmi_hid_set_line_cap(pcb_hid_gc_t gc, pcb_cap_style_t style);
void gpmi_hid_set_line_width(pcb_hid_gc_t gc, pcb_coord_t width);
void gpmi_hid_set_draw_xor(pcb_hid_gc_t gc, int xor);
void gpmi_hid_set_draw_faded(pcb_hid_gc_t gc, int faded);
void gpmi_hid_draw_line(pcb_hid_gc_t gc, pcb_coord_t x1, pcb_coord_t y1, pcb_coord_t x2, pcb_coord_t y2);
void gpmi_hid_draw_arc(pcb_hid_gc_t gc, pcb_coord_t cx, pcb_coord_t cy, pcb_coord_t xradius, pcb_coord_t yradius, pcb_angle_t start_angle, pcb_angle_t delta_angle);
void gpmi_hid_draw_rect(pcb_hid_gc_t gc, pcb_coord_t x1, pcb_coord_t y1, pcb_coord_t x2, pcb_coord_t y2);
void gpmi_hid_fill_circle(pcb_hid_gc_t gc, pcb_coord_t cx, pcb_coord_t cy, pcb_coord_t radius);
void gpmi_hid_fill_polygon(pcb_hid_gc_t gc, int n_coords, pcb_coord_t *x, pcb_coord_t *y);
void gpmi_hid_fill_polygon_offs(pcb_hid_gc_t gc, int n_coords, pcb_coord_t *x, pcb_coord_t *y, pcb_coord_t dx, pcb_coord_t dy);
void gpmi_hid_fill_pcb_polygon(pcb_hid_gc_t gc, pcb_poly_t *poly, const pcb_box_t *clip_box);
void gpmi_hid_fill_rect(pcb_hid_gc_t gc, pcb_coord_t x1, pcb_coord_t y1, pcb_coord_t x2, pcb_coord_t y2);

==> pcb-rnd_2.1.0.orig.tar.bz2: pcb-rnd-2.1.0/src_plugins/gpmi/pcb-gpmi/gpmi_plugin/gpmi_pkg/hid/hid_callbacks.h <==
pcb_hid_attribute_t *gpmi_hid_get_export_options(int *num);
pcb_hid_gc_t gpmi_hid_make_gc(void);
void gpmi_hid_destroy_gc(pcb_hid_gc_t gc);
void gpmi_hid_do_export(pcb_hid_attr_val_t * options);
int gpmi_hid_parse_arguments(int *pcbargc, char ***pcbargv);
void gpmi_hid_set_crosshair(pcb_coord_t x, pcb_coord_t y, int cursor_action);
int gpmi_hid_set_layer_group(pcb_layergrp_id_t group, const char *purpose, int purpi, pcb_layer_id_t layer, unsigned int flags, int is_empty, pcb_xform_t **xform);
void gpmi_hid_set_color(pcb_hid_gc_t gc, const char *name);
void gpmi_hid_set_line_cap(pcb_hid_gc_t gc, pcb_cap_style_t style);
void gpmi_hid_set_line_width(pcb_hid_gc_t gc, pcb_coord_t width);
void gpmi_hid_set_draw_xor(pcb_hid_gc_t gc, int xor);
void gpmi_hid_set_draw_faded(pcb_hid_gc_t gc, int faded);
void gpmi_hid_draw_line(pcb_hid_gc_t gc, pcb_coord_t x1, pcb_coord_t y1, pcb_coord_t x2, pcb_coord_t y2);
void gpmi_hid_draw_arc(pcb_hid_gc_t gc, pcb_coord_t cx, pcb_coord_t cy, pcb_coord_t xradius, pcb_coord_t yradius, pcb_angle_t start_angle, pcb_angle_t delta_angle);
void gpmi_hid_draw_rect(pcb_hid_gc_t gc, pcb_coord_t x1, pcb_coord_t y1, pcb_coord_t x2, pcb_coord_t y2);
void gpmi_hid_fill_circle(pcb_hid_gc_t gc, pcb_coord_t cx, pcb_coord_t cy, pcb_coord_t radius);
void gpmi_hid_fill_polygon(pcb_hid_gc_t gc, int n_coords, pcb_coord_t *x, pcb_coord_t *y);
void gpmi_hid_fill_polygon_offs(pcb_hid_gc_t gc, int n_coords, pcb_coord_t *x, pcb_coord_t *y, pcb_coord_t dx, pcb_coord_t dy);
void gpmi_hid_fill_pcb_polygon(pcb_hid_gc_t gc, pcb_poly_t *poly, const pcb_box_t *clip_box);
void gpmi_hid_fill_rect(pcb_hid_gc_t gc, pcb_coord_t x1, pcb_coord_t y1, pcb_coord_t x2, pcb_coord_t y2);
